.. _api:

API Reference
=============

Response
--------

.. autoclass:: pywreck.Response

Request API
-----------

.. autofunction:: pywreck.request

HTTP Method APIs
++++++++++++++++

When using HTTP method functions directly, the method string does not have to be specified in the function call parameters.

Supported methods:

* get
* head
* post
* put
* delete

Connection API
--------------

.. autoclass:: pywreck.Connection
